@@ -48,8 +48,6 @@ sub login {
     # First, try the actual login method against form variables
     my $username = $cgi->param("Bugzilla_login");
     my $passwd = $cgi->param("Bugzilla_password");
-    
-    $cgi->delete('Bugzilla_login', 'Bugzilla_password');
 
     my $authmethod = Param("loginmethod");
     my ($authres, $userid, $extra, $info) =
@@ -217,8 +215,12 @@ sub logout {
 
 sub clear_browser_cookies {
     my $cgi = Bugzilla->cgi;
-    $cgi->remove_cookie('Bugzilla_login');
-    $cgi->remove_cookie('Bugzilla_logincookie');
+    $cgi->send_cookie(-name => "Bugzilla_login",
+                      -value => "",
+                      -expires => "Tue, 15-Sep-1998 21:49:00 GMT");
+    $cgi->send_cookie(-name => "Bugzilla_logincookie",
+                      -value => "",
+                      -expires => "Tue, 15-Sep-1998 21:49:00 GMT");
 }
 
 1;
