@@ -19,25 +19,15 @@
 #
 # Contributor(s): Bradley Baetz <bbaetz@student.usyd.edu.au>
 #                 Byron Jones <bugzilla@glob.com.au>
-#                 Marc Schumann <wurblzap@gmail.com>
 
 use strict;
 
 package Bugzilla::CGI;
 
-BEGIN {
-    if ($^O =~ /MSWin32/i) {
-        # Help CGI find the correct temp directory as the default list
-        # isn't Windows friendly (Bug 248988)
-        $ENV{'TMPDIR'} = $ENV{'TEMP'} || $ENV{'TMP'} || "$ENV{'WINDIR'}\\TEMP";
-    }
-}
-
 use CGI qw(-no_xhtml -oldstyle_urls :private_tempfiles :unique_headers SERVER_PUSH);
 
 use base qw(CGI);
 
-use Bugzilla::Error;
 use Bugzilla::Util;
 use Bugzilla::Config;
 
@@ -56,21 +46,11 @@ sub new {
 
     my $self = $class->SUPER::new(@args);
 
-    # This happens here so that command-line scripts don't spit out
-    # their errors in HTML format.
-    require CGI::Carp;
-    import CGI::Carp qw(fatalsToBrowser);
-
     # Make sure our outgoing cookie list is empty on each invocation
     $self->{Bugzilla_cookie_list} = [];
 
-    # Send appropriate charset
-    $self->charset(Param('utf8') ? 'UTF-8' : '');
-
-    # Redirect to SSL if required
-    if (Param('sslbase') ne '' and Param('ssl') eq 'always' and i_am_cgi()) {
-        $self->require_https(Param('sslbase'));
-    }
+    # Make sure that we don't send any charset headers
+    $self->charset('');
 
     # Check for errors
     # All of the Bugzilla code wants to do this, so do it here instead of
@@ -120,7 +100,7 @@ sub canonicalise_query {
         my $esc_key = url_quote($key);
 
         foreach my $value ($self->param($key)) {
-            if (defined($value)) {
+            if ($value) {
                 my $esc_value = url_quote($value);
 
                 push(@parameters, "$esc_key=$esc_value");
@@ -152,7 +132,7 @@ sub multipart_init {
     # Note: CGI.pm::multipart_init up to v3.04 explicitly set nph to 0
     # CGI.pm::multipart_init v3.05 explicitly sets nph to 1
     # CGI.pm's header() sets nph according to a param or $CGI::NPH, which
-    # is the desired behaviour.
+    # is the desired behavour.
 
     # Allow multiple calls to $cgi->header()
     $CGI::HEADERS_ONCE = 0;
@@ -187,64 +167,24 @@ sub multipart_start {
 }
 
 # The various parts of Bugzilla which create cookies don't want to have to
-# pass them around to all of the callers. Instead, store them locally here,
+# pass them arround to all of the callers. Instead, store them locally here,
 # and then output as required from |header|.
 sub send_cookie {
     my $self = shift;
 
-    # Move the param list into a hash for easier handling.
-    my %paramhash;
-    my @paramlist;
-    my ($key, $value);
-    while ($key = shift) {
-        $value = shift;
-        $paramhash{$key} = $value;
-    }
+    # Add the default path in
+    unshift(@_, '-path' => Param('cookiepath'));
 
-    # Complain if -value is not given or empty (bug 268146).
-    if (!exists($paramhash{'-value'}) || !$paramhash{'-value'}) {
-        ThrowCodeError('cookies_need_value');
-    }
+    # Use CGI::Cookie directly, because CGI.pm's |cookie| method gives the
+    # current value if there isn't a -value attribute, which happens when
+    # we're expiring an entry.
+    require CGI::Cookie;
+    my $cookie = CGI::Cookie->new(@_);
+    push @{$self->{Bugzilla_cookie_list}}, $cookie;
 
-    # Add the default path and the domain in.
-    $paramhash{'-path'} = Param('cookiepath');
-    $paramhash{'-domain'} = Param('cookiedomain') if Param('cookiedomain');
-
-    # Move the param list back into an array for the call to cookie().
-    foreach (keys(%paramhash)) {
-        unshift(@paramlist, $_ => $paramhash{$_});
-    }
-
-    push(@{$self->{'Bugzilla_cookie_list'}}, $self->cookie(@paramlist));
+    return;
 }
 
-# Cookies are removed by setting an expiry date in the past.
-# This method is a send_cookie wrapper doing exactly this.
-sub remove_cookie {
-    my $self = shift;
-    my ($cookiename) = (@_);
-
-    # Expire the cookie, giving a non-empty dummy value (bug 268146).
-    $self->send_cookie('-name'    => $cookiename,
-                       '-expires' => 'Tue, 15-Sep-1998 21:49:00 GMT',
-                       '-value'   => 'X');
-}
-
-# Redirect to https if required
-sub require_https {
-    my $self = shift;
-    if ($self->protocol ne 'https') {
-        my $url = shift;
-        if (defined $url) {
-            $url .= $self->url('-path_info' => 1, '-query' => 1, '-relative' => 1);
-        } else {
-            $url = $self->self_url;
-            $url =~ s/^http:/https:/i;
-        }
-        print $self->redirect(-location => $url);
-        exit;
-    }
-}
 
 1;
 
@@ -292,29 +232,11 @@ Values in C<@exclude> are not included in the result.
 
 =item C<send_cookie>
 
-This routine is identical to the cookie generation part of CGI.pm's C<cookie>
-routine, except that it knows about Bugzilla's cookie_path and cookie_domain
-parameters and takes them into account if necessary.
-This should be used by all Bugzilla code (instead of C<cookie> or the C<-cookie>
-argument to C<header>), so that under mod_perl the headers can be sent
-correctly, using C<print> or the mod_perl APIs as appropriate.
-
-To remove (expire) a cookie, use C<remove_cookie>.
-
-=item C<remove_cookie>
-
-This is a wrapper around send_cookie, setting an expiry date in the past,
-effectively removing the cookie.
-
-As its only argument, it takes the name of the cookie to expire.
-
-=item C<require_https($baseurl)>
-
-This routine checks if the current page is being served over https, and
-redirects to the https protocol if required, retaining QUERY_STRING.
-
-It takes an option argument which will be used as the base URL.  If $baseurl
-is not provided, the current URL is used.
+This routine is identical to CGI.pm's C<cookie> routine, except that the cookie
+is sent to the browser, rather than returned. This should be used by all
+Bugzilla code (instead of C<cookie> or the C<-cookie> argument to C<header>),
+so that under mod_perl the headers can be sent correctly, using C<print> or
+the mod_perl APIs as appropriate.
 
 =back
 
