@@ -25,8 +25,6 @@
 #                 J. Paul Reed <preed@sigkill.com>
 #                 Bradley Baetz <bbaetz@student.usyd.edu.au>
 #                 Christopher Aillon <christopher@aillon.com>
-#                 Erik Stambaugh <erik@dasbistro.com>
-#                 Frédéric Buclin <LpSolit@gmail.com>
 
 package Bugzilla::Config;
 
@@ -34,6 +32,8 @@ use strict;
 
 use base qw(Exporter);
 
+use Bugzilla::Util;
+
 # Under mod_perl, get this from a .htaccess config variable,
 # and/or default from the current 'real' dir
 # At some stage after this, it may be possible for these dir locations
@@ -44,34 +44,19 @@ use base qw(Exporter);
 # .pms elsewhere.
 # $webdotdir must be in the webtree somewhere. Even if you use a local dot,
 # we output images to there. Also, if $webdot dir is not relative to the
-# bugzilla root directory, you'll need to change showdependencygraph.cgi to
+# bugzilla root directory, you'll need to change showdependancygraph.cgi to
 # set image_url to the correct location.
 # The script should really generate these graphs directly...
-# Note that if $libpath is changed, some stuff will break, notably dependency
+# Note that if $libpath is changed, some stuff will break, notably dependancy
 # graphs (since the path will be wrong in the HTML). This will be fixed at
 # some point.
 
-# constant paths
 our $libpath = '.';
+our $localconfig = "$libpath/localconfig";
+our $datadir = "$libpath/data";
 our $templatedir = "$libpath/template";
-
-# variable paths
-our $project;
-our $localconfig;
-our $datadir;
-if ($ENV{'PROJECT'} && $ENV{'PROJECT'} =~ /^(\w+)$/) {
-    $project = $1;
-    $localconfig = "$libpath/localconfig.$project";
-    $datadir = "$libpath/data/$project";
-} else {
-    $localconfig = "$libpath/localconfig";
-    $datadir = "$libpath/data";
-}
-our $attachdir = "$datadir/attachments";
 our $webdotdir = "$datadir/webdot";
 
-our @parampanels = ();
-
 # Module stuff
 @Bugzilla::Config::EXPORT = qw(Param);
 
@@ -84,16 +69,14 @@ our @parampanels = ();
 
 %Bugzilla::Config::EXPORT_TAGS =
   (
-   admin => [qw(UpdateParams SetParam WriteParams)],
-   db => [qw($db_driver $db_host $db_port $db_name $db_user $db_pass $db_sock)],
-   locations => [qw($libpath $localconfig $attachdir $datadir $templatedir
-                    $webdotdir $project)],
-   params => [qw(@parampanels)],
+   admin => [qw(GetParamList UpdateParams SetParam WriteParams)],
+   db => [qw($db_host $db_port $db_name $db_user $db_pass $db_sock)],
+   locations => [qw($libpath $localconfig $datadir $templatedir $webdotdir)],
   );
-Exporter::export_ok_tags('admin', 'db', 'locations', 'params');
+Exporter::export_ok_tags('admin', 'db', 'locations');
 
 # Bugzilla version
-$Bugzilla::Config::VERSION = "2.22.1";
+$Bugzilla::Config::VERSION = "2.18";
 
 use Safe;
 
@@ -143,21 +126,17 @@ sub _load_datafiles {
 # Load in the datafiles
 _load_datafiles();
 
+# Load in the param defintions
+unless (my $ret = do 'defparams.pl') {
+    die "Couldn't parse defparams.pl: $@" if $@;
+    die "Couldn't do defparams.pl: $!" unless defined $ret;
+    die "Couldn't run defparams.pl" unless $ret;
+}
+
 # Stick the params into a hash
 my %params;
-
-# Load in the param definitions
-foreach my $item ((glob "$libpath/Bugzilla/Config/*.pm")) {
-    $item =~ m#/([^/]+)\.pm$#;
-    my $module = $1;
-    next if ($module eq 'Common');
-    require "Bugzilla/Config/$module.pm";
-    my @new_param_list = "Bugzilla::Config::$module"->get_param_list();
-    foreach my $item (@new_param_list) {
-        $params{$item->{'name'}} = $item;
-    }
-    push(@parampanels, $module);
-    push(@param_list, @new_param_list);
+foreach my $item (@param_list) {
+    $params{$item->{'name'}} = $item;
 }
 
 # END INIT CODE
@@ -182,6 +161,10 @@ sub Param {
     die "No value for param $param (try running checksetup.pl again)";
 }
 
+sub GetParamList {
+    return @param_list;
+}
+
 sub SetParam {
     my ($name, $value) = @_;
 
@@ -192,8 +175,8 @@ sub SetParam {
     # sanity check the value
 
     # XXX - This runs the checks. Which would be good, except that
-    # check_shadowdb creates the database as a side effect, and so the
-    # checker fails the second time around...
+    # check_shadowdb creates the database as a sideeffect, and so the
+    # checker fails the second time arround...
     if ($name ne 'shadowdb' && exists $entry->{'checker'}) {
         my $err = $entry->{'checker'}->($value, $entry);
         die "Param $name is not valid: $err" unless $err eq '';
@@ -205,27 +188,14 @@ sub SetParam {
 sub UpdateParams {
     # --- PARAM CONVERSION CODE ---
 
-    # Note that this isn't particularly 'clean' in terms of separating
+    # Note that this isn't particuarly 'clean' in terms of separating
     # the backend code (ie this) from the actual params.
     # We don't care about that, though
 
-    # Old Bugzilla versions stored the version number in the params file
+    # Old bugzilla versions stored the version number in the params file
     # We don't want it, so get rid of it
     delete $param{'version'};
 
-    # Change from usebrowserinfo to defaultplatform/defaultopsys combo
-    if (exists $param{'usebrowserinfo'}) {
-        if (!$param{'usebrowserinfo'}) {
-            if (!exists $param{'defaultplatform'}) {
-                $param{'defaultplatform'} = 'Other';
-            }
-            if (!exists $param{'defaultopsys'}) {
-                $param{'defaultopsys'} = 'Other';
-            }
-        }
-        delete $param{'usebrowserinfo'};
-    }
-
     # Change from a boolean for quips to multi-state
     if (exists $param{'usequip'} && !exists $param{'enablequips'}) {
         $param{'enablequips'} = $param{'usequip'} ? 'on' : 'off';
@@ -247,26 +217,6 @@ sub UpdateParams {
         $param{'loginmethod'} = $param{'useLDAP'} ? "LDAP" : "DB";
     }
 
-    # set verify method to whatever loginmethod was
-    if (exists $param{'loginmethod'} && !exists $param{'user_verify_class'}) {
-        $param{'user_verify_class'} = $param{'loginmethod'};
-        delete $param{'loginmethod'};
-    }
-
-    # Remove quip-display control from parameters
-    # and give it to users via User Settings (Bug 41972)
-    if ( exists $param{'enablequips'} 
-         && !exists $param{'quip_list_entry_control'}) 
-    {
-        my $new_value;
-        ($param{'enablequips'} eq 'on')       && do {$new_value = 'open';};
-        ($param{'enablequips'} eq 'approved') && do {$new_value = 'moderated';};
-        ($param{'enablequips'} eq 'frozen')   && do {$new_value = 'closed';};
-        ($param{'enablequips'} eq 'off')      && do {$new_value = 'closed';};
-        $param{'quip_list_entry_control'} = $new_value;
-        delete $param{'enablequips'};
-    }
-
     # --- DEFAULTS FOR NEW PARAMS ---
 
     foreach my $item (@param_list) {
@@ -315,8 +265,8 @@ sub WriteParams {
     ChmodDataFile("$datadir/params", 0666);
 }
 
-# Some files in the data directory must be world readable if and only if
-# we don't have a webserver group. Call this function to do this.
+# Some files in the data directory must be world readable iff we don't have
+# a webserver group. Call this function to do this.
 # This will become a private function once all the datafile handling stuff
 # moves into this package
 
@@ -331,6 +281,45 @@ sub ChmodDataFile {
     chmod $perm,$file;
 }
 
+sub check_multi {
+    my ($value, $param) = (@_);
+
+    if ($param->{'type'} eq "s") {
+        unless (lsearch($param->{'choices'}, $value) >= 0) {
+            return "Invalid choice '$value' for single-select list param '$param'";
+        }
+
+        return "";
+    }
+    elsif ($param->{'type'} eq "m") {
+        foreach my $chkParam (@$value) {
+            unless (lsearch($param->{'choices'}, $chkParam) >= 0) {
+                return "Invalid choice '$chkParam' for multi-select list param '$param'";
+            }
+        }
+
+        return "";
+    }
+    else {
+        return "Invalid param type '$param->{'type'}' for check_multi(); " .
+          "contact your Bugzilla administrator";
+    }
+}
+
+sub check_numeric {
+    my ($value) = (@_);
+    if ($value !~ /^[0-9]+$/) {
+        return "must be a numeric value";
+    }
+    return "";
+}
+
+sub check_regexp {
+    my ($value) = (@_);
+    eval { qr/$value/ };
+    return $@;
+}
+
 1;
 
 __END__
@@ -349,6 +338,7 @@ Bugzilla::Config - Configuration parameters for Bugzilla
   # Administration functions
   use Bugzilla::Config qw(:admin);
 
+  my @valid_params = GetParamList();
   my @removed_params = UpgradeParams();
   SetParam($param, $value);
   WriteParams();
@@ -374,6 +364,13 @@ Parameters can be set, retrieved, and updated.
 Returns the Param with the specified name. Either a string, or, in the case
 of multiple-choice parameters, an array reference.
 
+=item C<GetParamList()>
+
+Returns the list of known parameter types, from defparams.pl. Users should not
+rely on this method; it is intended for editparams/doeditparams only
+
+The format for the list is specified in defparams.pl
+
 =item C<SetParam($name, $value)>
 
 Sets the param named $name to $value. Values are checked using the checker
@@ -393,7 +390,11 @@ Writes the parameters to disk.
 
 =back
 
-=over
+=head2 Parameter checking functions
+
+All parameter checking functions are called with two parameters:
+
+=over 4
 
 =item *
 
@@ -403,6 +404,24 @@ The new value for the parameter
 
 A reference to the entry in the param list for this parameter
 
+=back
+
 Functions should return error text, or the empty string if there was no error.
 
+=over 4
+
+=item C<check_multi>
+
+Checks that a multi-valued parameter (ie type C<s> or type C<m>) satisfies
+its contraints.
+
+=item C<check_numeric>
+
+Checks that the value is a valid number
+
+=item C<check_regexp>
+
+Checks that the value is a valid regexp
+
 =back
+
