@@ -1,4 +1,4 @@
-#!/usr/bonsaitools/bin/perl -w 
+#!/usr/bin/perl -w 
 # -*- Mode: perl; indent-tabs-mode: nil -*-
 #
 # The contents of this file are subject to the Mozilla Public
@@ -25,7 +25,6 @@
 # a new bug into bugzilla. Everything before the beginning <?xml line
 # is removed so you can pipe in email messages.
 
-use diagnostics;
 use strict;
 
 #####################################################################
@@ -60,29 +59,31 @@ BEGIN {
 chdir $::path;
 use lib ($::path);
 
+use Bugzilla;
+use Bugzilla::Config qw(:DEFAULT $datadir);
+use Bugzilla::BugMail;
+
 use XML::Parser;
 use Data::Dumper;
 $Data::Dumper::Useqq = 1;
+use Bugzilla::BugMail;
 
 require "CGI.pl";
 require "globals.pl";
 $::lockcount = 0;
 
 GetVersionTable();
-ConnectToDatabase();
 
 
 sub sillyness {
     my $zz;
     $zz = $Data::Dumper::Useqq;
-    $zz = %::components;
     $zz = %::versions;
     $zz = %::keywordsbyname;
     $zz = @::legal_bug_status;
     $zz = @::legal_opsys;
     $zz = @::legal_platform;
     $zz = @::legal_priority;
-    $zz = @::legal_product;
     $zz = @::legal_severity;
     $zz = @::legal_resolution;
     $zz = %::target_milestone;
@@ -113,11 +114,8 @@ sub MailMessage {
   $header.= "From: Bugzilla <$from>\n";
   $header.= "Subject: $subject\n\n";
 
-  open(SENDMAIL,
-    "|/usr/lib/sendmail -ODeliveryMode=background -t -i") ||
-      die "Can't open sendmail";
-  print SENDMAIL $header . $message . "\n";
-  close SENDMAIL;
+  my $sendmessage = $header . $message . "\n";
+  Bugzilla::BugMail::MessageToMTA($sendmessage);
 
   Log($subject . " sent to: $to");
 }
@@ -126,7 +124,7 @@ sub MailMessage {
 sub Log {
     my ($str) = (@_);
     Lock();
-    open(FID, ">>data/maillog") || die "Can't write to data/maillog";
+    open(FID, ">>$datadir/maillog") || die "Can't write to $datadir/maillog";
     print FID time2str("%D %H:%M", time()) . ": $str\n";
     close FID;
     Unlock();
@@ -135,13 +133,13 @@ sub Log {
 sub Lock {
     if ($::lockcount <= 0) {
         $::lockcount = 0;
-        open(LOCKFID, ">>data/maillock") || die "Can't open data/maillock: $!";
+        open(LOCKFID, ">>$datadir/maillock") || die "Can't open $datadir/maillock: $!";
         my $val = flock(LOCKFID,2);
         if (!$val) { # '2' is magic 'exclusive lock' const.
-            print "Content-type: text/html\n\n";
+            print Bugzilla->cgi->header();
             print "Lock failed: $val\n";
         }
-        chmod 0666, "data/maillock";
+        chmod 0666, "$datadir/maillock";
     }
     $::lockcount++;
 }
@@ -229,7 +227,7 @@ if (defined $tree->[1][0]->{'urlbase'}) {
 }
   
 
-my $bugqty = ($#{@{$tree}->[1]} +1 -3) / 4;
+my $bugqty = ($#{$tree->[1]} +1 -3) / 4;
 my $log = "Imported $bugqty bug(s) from $urlbase,\n  sent by $exporter.\n\n";
 for (my $k=1 ; $k <= $bugqty ; $k++) {
   my $cur = $k*4;
@@ -263,7 +261,7 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
  
   my %bug_fields;
   my $err = "";
-  for (my $i=3 ; $i < $#{@{$tree}->[1][$cur]} ; $i=$i+4) {
+  for (my $i=3 ; $i < $#{$tree->[1][$cur]} ; $i=$i+4) {
     if (defined $multiple_fields{$tree->[1][$cur][$i]}) {
       if (defined $bug_fields{$tree->[1][$cur][$i]}) {
         $bug_fields{$tree->[1][$cur][$i]} .= " " .  $tree->[1][$cur][$i+1][2];
@@ -279,7 +277,7 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
       $err .= "<$tree->[1][$cur][$i]>";
       if (defined $tree->[1][$cur][$i+1][3]) {
         $err .= "\n";
-        for (my $j=3 ; $j < $#{@{$tree}->[1][$cur][$i+1]} ; $j=$j+4) {
+        for (my $j=3 ; $j < $#{$tree->[1][$cur][$i+1]} ; $j=$j+4) {
           $err .= "  <". $tree->[1][$cur][$i+1][$j] . ">";
           $err .= " $tree->[1][$cur][$i+1][$j+1][2] ";
           $err .= "</". $tree->[1][$cur][$i+1][$j] . ">\n";
@@ -292,7 +290,7 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
   }
 
   my @long_descs;
-  for (my $i=3 ; $i < $#{@{$tree}->[1][$cur]} ; $i=$i+4) {
+  for (my $i=3 ; $i < $#{$tree->[1][$cur]} ; $i=$i+4) {
     if ($tree->[1][$cur][$i] =~ /long_desc/) {
       my %long_desc;
       $long_desc{'who'} = $tree->[1][$cur][$i+1][4][2];
@@ -372,20 +370,34 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
      $comp = $default_comp;
   }
 
+  # XXX - why are these arrays??
   my @product;
   my @component;
-  if ((@product = grep /^$prod$/i, @::legal_product) &&
-      (@component = grep /^$comp$/i, @{$::components{$product[0]}}) ) {
-    push (@query, "product");
-    push (@values, SqlQuote($product[0]) );
-    push (@query, "component");
-    push (@values, SqlQuote($component[0]) );
-  } elsif ((@product = grep /^$default_prod$/i, @::legal_product) &&
-      (@component = grep /^$default_comp$/i, @{$::components{$product[0]}}) ) {
-    push (@query, "product");
-    push (@values, SqlQuote($product[0]) );
-    push (@query, "component");
-    push (@values, SqlQuote($component[0]) );
+  my $prod_id;
+  my $comp_id;
+
+  # First, try the given product/component
+  $prod_id = get_product_id($prod);
+  $comp_id = get_component_id($prod_id, $comp) if $prod_id;
+
+  if ($prod_id && $comp_id) {
+      $product[0] = $prod;
+      $component[0] = $comp;
+  } else {
+      # Second, try the defaults
+      $prod_id = get_product_id($default_prod);
+      $comp_id = get_component_id($prod_id, $default_comp) if $prod_id;
+      if ($prod_id && $comp_id) {
+          $product[0] = $default_prod;
+          $component[0] = $default_comp;
+      }
+  }
+
+  if ($prod_id && $comp_id) {
+    push (@query, "product_id");
+    push (@values, $prod_id );
+    push (@query, "component_id");
+    push (@values, $comp_id );
   } else {
     my $subject = "Bug import error: invalid default product or component";
     my $message = "Cannot import these bugs because an invalid default ";
@@ -406,9 +418,9 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
     push (@query, "version");
   } else {
     push (@query, "version");
-    push (@values, SqlQuote(@{$::versions{$product[0]}}->[0]));
+    push (@values, SqlQuote($::versions{$product[0]}->[0]));
     $err .= "Unknown version $bug_fields{'version'} in product $product[0]. ";
-    $err .= "Setting version to \"@{$::versions{$product[0]}}->[0]\".\n";
+    $err .= "Setting version to \"$::versions{$product[0]}->[0]\".\n";
   }
 
   if (defined ($bug_fields{'priority'}) &&
@@ -456,7 +468,7 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
       push (@query, "target_milestone");
     } else {
       SendSQL("SELECT defaultmilestone FROM products " .
-              "WHERE product = " . SqlQuote($product[0]));
+              "WHERE name = " . SqlQuote($product[0]));
       my $tm = FetchOneColumn();
       push (@values, SqlQuote($tm));
       push (@query, "target_milestone");
@@ -567,14 +579,15 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
     my $qa_contact;
     if ( (defined $bug_fields{'qa_contact'}) &&
          ($qa_contact  = DBname_to_id($bug_fields{'qa_contact'})) ){
-      push (@values, SqlQuote($qa_contact));
+      push (@values, $qa_contact);
       push (@query, "qa_contact");
     } else {
-      SendSQL("select initialqacontact from components where program=" .
-              SqlQuote($product[0]) .
-              " and value=" . SqlQuote($component[0]) );
+      SendSQL("SELECT initialqacontact FROM components, products " .
+              "WHERE components.product_id = products.id" .
+              " AND products.name = " . SqlQuote($product[0]) .
+              " AND components.name = " . SqlQuote($component[0]) );
       $qa_contact = FetchOneColumn();
-      push (@values, SqlQuote(DBname_to_id($qa_contact)) );
+      push (@values, $qa_contact);
       push (@query, "qa_contact");
       $err .= "Setting qa contact to the default for this product.\n";
       $err .= "   This bug either had no qa contact or an invalid one.\n";
@@ -636,7 +649,7 @@ for (my $k=1 ; $k <= $bugqty ; $k++) {
     $log .= "\n\n\n";
   }
 
-  system("./processmail", $id, $exporter);
+  Bugzilla::BugMail::Send($id, { 'changer' => $exporter });
 }
 
 my $subject = "$bugqty bug(s) successfully moved from $urlbase to " 
